%define stable_part 3.1.4

Name:           cosign
Version:        %stable_part
Release:        3%{?dist}
Summary:        Secure, Intra-Institutional Web Authentication

Group:          System Environment/Daemons
License:        MIT?
URL:            http://weblogin.org/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        cosign.init
Patch1:		cosign-sasl2.patch
Patch2:         cosign-configure.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  httpd-devel, cyrus-sasl-devel, openssl-devel, mysql-devel
#BuildRequires:  autoconf, automake
Requires:       /usr/sbin/useradd
Requires:       %{name}-mod_cosign
# required for c_rehash
Requires:       openssl-perl


%description
An open source project originally designed to provide the University of
Michigan with a secure single sign-on web authentication system. cosign is
part of the National Science Foundation Middleware Initiative (NMI) EDIT
software release.


%package libsnet
Summary:        Cosign libsnet module
Group:		System Environment/Libraries

%description libsnet
libsnet dynamic library for cosign.


%package libsnet-devel
Summary:        Header files and libraries for the Cosign libsnet
Group:		Development/Libraries

%description libsnet-devel
Header files and libraries for the Cosign libsnet.


%package mod_cosign
Summary:        Cosign module for apache
Group:          System Environment/Daemons
Requires:       httpd, mod_ssl

%description mod_cosign
Cosgin module for apache.


%prep
%setup -q -n %{name}-%{version}
%patch1 -p1
%patch2 -p1


%build
export LDFLAGS="-L/usr/lib64 -lcrypt"
#aclocal && autoreconf
%configure \
  --libdir=%{_libdir} \
  --enable-apache2=%{_sbindir}/apxs \
  --enable-krb --with-gss --enable-mysql \
  --with-filterdb=%{_var}/lib/cosign/filter \
  --with-cosignconf=%{_sysconfdir}/%{name}.conf \
  --with-cosigncadir=%{_sysconfdir}/pki/cosign/CA \
  --with-cosigncert=%{_sysconfdir}/pki/cosign/cert.pem \
  --with-cosignkey=%{_sysconfdir}/pki/cosign/key.pem \
  --with-ticketcache=%{_var}/lib/cosign/ticket
cd libsnet
%configure --libdir=%{_libdir} --enable-shared --disable-static
make snet.o
make
cd ..
# somethings wrong with parallel build, try to build again
make %{?_smp_mflags} everything \
  || make everything -j1
chmod -x LICENSE VERSION README*
# update perl path
sed -i 's|/usr/local/bin|/usr/bin|g' scripts/logout/logout.pl \
  helloCosign/helloCosign.pl helloCosign/helloCosign.py


%install
rm -rf $RPM_BUILD_ROOT
LIBEXECDIR=$RPM_BUILD_ROOT/`apxs -q LIBEXECDIR`
mkdir -p $LIBEXECDIR
make -C libsnet install DESTDIR=$RPM_BUILD_ROOT \
  libdir=$RPM_BUILD_ROOT/%{_libdir} \
  includedir=$RPM_BUILD_ROOT/%{_includedir}
make install-all DESTDIR=$RPM_BUILD_ROOT \
  APXS2="apxs -S LIBEXECDIR=$LIBEXECDIR" \
  prefix=$RPM_BUILD_ROOT/%{_prefix} \
  SBINDIR=$RPM_BUILD_ROOT/%{_sbindir} \
  MANDIR=$RPM_BUILD_ROOT/%{_mandir} \
  CGIDIR=$RPM_BUILD_ROOT/%{_var}/www/cosign/cgi-bin \
  TMPLDIR=$RPM_BUILD_ROOT/%{_var}/www/cosign/templates \
  HTMLDIR=$RPM_BUILD_ROOT/%{_var}/www/cosign/html \
  SERVICESDIR=$RPM_BUILD_ROOT/%{_var}/www/cosign/services
# remove some scripts
rm -rf scripts/{cron,startup}
# install dirs
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/pki/cosign/CA \
  $RPM_BUILD_ROOT/%{_var}/lib/cosign/{daemon,ticket,filter}
# install init script
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d
cp -a %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/rc.d/init.d/cosign
# default config
cat << EOF > $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}.conf
# TLS parameters
#set cosigncadir /etc/pki/cosign/CA
#set cosigncert /etc/pki/cosign/cert.pem
#set cosignkey /etc/pki/cosign/key.pem

cgi localhost

set cosignhost localhost
set cosigndb /var/lib/cosign/daemon
set cosigntmpldir /var/www/cosign/templates
set cosignlogouturl https://localhost/
set cosignloopurl https://localhost/cosign/looping.html

# Grab this user's factor:
# - argument 3 and later are name(s) of <FORM>/POST fields from the template
# - at least one factor is required for authentication to succeed
# - a factor executable only returns 1 factor name
# - factor names can be used by mod_cosign (CosignRequireFactor)
# - "-2" means this secondary script is started only if another one was successful
#factor /usr/lib/cosign/factor/123magic.sh login password
#factor /usr/lib/cosign/factor/ldap login password
#factor /usr/lib/cosign/factor/admin -2 login

#passwd kerberos ([^@]+) $1 EXAMPLE.COM
EOF

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/httpd/conf.d
cat << EOF > $RPM_BUILD_ROOT/%{_sysconfdir}/httpd/conf.d/cosign.conf
RedirectMatch ^/$ https://localhost/cosign-bin/cosign.cgi
ScriptAlias /cosign-bin/ /var/www/cosign/cgi-bin/
Alias /cosign /var/www/cosign/html
EOF
cat << EOF > $RPM_BUILD_ROOT/%{_sysconfdir}/httpd/conf.d/mod_cosign.conf
LoadModule cosign_module modules/mod_cosign.so

CosignProtected Off
CosignHostname localhost
CosignRedirect https://localhost/cosign-bin/cosign.cgi
CosignPostErrorRedirect https://localhost/cosign/post_error.html
CosignService simpleservice
CosignCrypto /etc/pki/cosign/key.pem /etc/pki/cosign/cert.pem /etc/pki/cosign/CA

<Directory "/var/www/html">
  CosignProtected On
</Directory>
EOF


%clean
rm -rf $RPM_BUILD_ROOT


%pre
/usr/sbin/useradd -c "COSIGN" -s /sbin/nologin -r -d /var/lib/cosign/daemon cosign 2>/dev/null || :
# update /etc/services
getent services cosign >/dev/null \
  || echo "cosign 6663/tcp" >> /etc/services


%files
%defattr(-,root,root,-)
%doc CHANGELOG Contributors LICENSE README README.basicauth VERSION scripts
%dir %{_sysconfdir}/pki/cosign
%dir %{_sysconfdir}/pki/cosign/CA
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%{_sysconfdir}/rc.d/init.d/cosign
%dir %{_var}/www/cosign
%dir %{_var}/www/cosign/cgi-bin
%dir %{_var}/www/cosign/templates
%dir %{_var}/www/cosign/html
%dir %{_var}/www/cosign/services
%{_var}/www/cosign/templates/*
%{_var}/www/cosign/html/*
%{_var}/www/cosign/services/*
%{_var}/www/cosign/cgi-bin/*
%{_sbindir}/*
%{_mandir}/*/*
%attr(-,cosign,cosign) %dir %{_var}/lib/cosign/daemon
%attr(770,apache,cosign) %dir %{_var}/lib/cosign/filter
%attr(770,cosign,apache) %dir %{_var}/lib/cosign/ticket


%files libsnet
%{_libdir}/libsnet*.so.*

%files libsnet-devel
%{_libdir}/libsnet*.so
%{_libdir}/libsnet*.la
%{_includedir}/*


%files mod_cosign
%doc CHANGELOG VERSION README README.weblogin helloCosign
%config(noreplace) %{_sysconfdir}/httpd/conf.d/mod_%{name}.conf
%{_libdir}/httpd/modules/*.so


%changelog
* Fri Nov 7 2008 Jan ONDREJ (SAL) <ondrejj(at)salstar.sk> - 2.1.0-1.rc2
- initial release
